@@ -15,12 +15,14 @@ import copy
 def login_info(
         username: str,
         password: str,
-        img_code: str = None  # 验证码
+        img_code: str = None,  # 验证码
+        cookie: str = None
 ) -> json:
     """
     :param username: 登录账号名
     :param password: 登录密码
     :param img_code: 验证码
+    :param cookie: 小饼干
     尝试使用帐号密码登录，返回尝试的结果，可能会有如下结果：
     正常
     有限封
@@ -58,7 +60,8 @@ def login_info(
         "Sec-Fetch-Site": "same-origin",
         "TE": "trailers",
         "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:97.0) Gecko/20100101 Firefox/97.0",
-        "X-Requested-With": "XMLHttpRequest"
+        "X-Requested-With": "XMLHttpRequest",
+        "Cookie": cookie
     }
     temp_session = requests.session()
     response = temp_session.request(
@@ -102,6 +105,7 @@ def login_info(
 
             base_resp = response2_json.get('base_resp')
             ret2 = base_resp.get('ret')
+            err_msg2 = base_resp.get('err_msg')
 
             account = response2_json.get('account')
             punish_id = response2_json.get('punish_id')
@@ -111,6 +115,9 @@ def login_info(
             if ret2 == 200007:
                 return_json['account_state'] = 4
                 return_json['msg'] = "帐号注销"
+            elif ret2 == 200003:
+                return_json['account_state'] = -2
+                return_json['msg'] = err_msg2
             elif account is not None:
                 return_json['account_state'] = 0
                 return_json['msg'] = "帐号正常"
